# handyderivatives

Install with pip for the easiest use.

`pip install handyderivatives`

[https://pypi.org/project/handyderivatives/](https://pypi.org/project/handyderivatives/)

## Running it
`handyderivatives functions.txt`

## How to use it
It gets the derivatives for differentiable functions of a single variable.

Edit a file that looks like this. 

![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/file.png)

To get output that looks like this. LaTex output is included.

**If you install with pip just run handyderivatives, this image was from before it was published.**

![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/output.png)
